@@ -27,41 +27,41 @@ plotmat <- function(A, pos=NULL, curve=NULL, name=NULL, absent=0,
     A <- matrix(nrow=nrow(A), ncol=ncol(A), data=A)
 
   if (length (box.size)    < ncomp)
-    box.size  <- rep(box.size, len=ncomp)
+    box.size  <- rep(box.size, length.out=ncomp)
   if (length (box.prop)    < ncomp)
-    box.prop  <- rep(box.prop, len=ncomp)
+    box.prop  <- rep(box.prop, length.out=ncomp)
   if (length (box.type)    < ncomp)
-    box.type  <- rep(box.type, len=ncomp)
+    box.type  <- rep(box.type, length.out=ncomp)
   if (length (box.col)     < ncomp)
-    box.col   <- rep(box.col , len=ncomp)
+    box.col   <- rep(box.col , length.out=ncomp)
   if (length (box.lcol)    < ncomp)
-    box.lcol  <- rep(box.lcol, len=ncomp)
+    box.lcol  <- rep(box.lcol, length.out=ncomp)
   if (length (box.cex)     < ncomp)
-    box.cex   <- rep(box.cex , len=ncomp)
+    box.cex   <- rep(box.cex , length.out=ncomp)
   if (length (box.lwd)     < ncomp)
-    box.lwd   <- rep(box.lwd , len=ncomp)
+    box.lwd   <- rep(box.lwd , length.out=ncomp)
   if (length (txt.col)     < ncomp)
-    txt.col   <- rep(txt.col , len=ncomp)
+    txt.col   <- rep(txt.col , length.out=ncomp)
 
   if (length (shadow.size) < ncomp)
-    shadow.size  <- rep(shadow.size, len=ncomp)
+    shadow.size  <- rep(shadow.size, length.out=ncomp)
   if (length (shadow.col)  < ncomp)
-    shadow.col   <- rep(shadow.col , len=ncomp)
+    shadow.col   <- rep(shadow.col , length.out=ncomp)
   selflwd    <- self.lwd
   selfcex    <- self.cex
   selfarrpos <- self.arrpos
   if (length (selfarrpos)  < ncomp)
-    selfarrpos<- rep(selfarrpos, len=ncomp)
+    selfarrpos<- rep(selfarrpos, length.out=ncomp)
   if (length (selflwd)     < ncomp)
-    selflwd<- rep(selflwd, len=ncomp)
+    selflwd<- rep(selflwd, length.out=ncomp)
   if (length (selfcex)     < ncomp)
-    selfcex<- rep(selfcex, len=ncomp)
+    selfcex<- rep(selfcex, length.out=ncomp)
   if (length (self.shiftx) < ncomp)
-    self.shiftx<- rep(self.shiftx, len=ncomp)
+    self.shiftx<- rep(self.shiftx, length.out=ncomp)
   if (is.null(self.shifty))
     self.shifty <- self.shiftx*box.prop
   if (length(self.shifty)  < ncomp)
-     self.shifty<- rep(self.shifty, len=ncomp)
+     self.shifty<- rep(self.shifty, length.out=ncomp)
   if (is.null(curve))
     curve   <- NA
   if (length(curve)==1)
